==> wiki3_4_0.zip: wiki3_4_0/plugin/admin/AdminPageHandler.pm <==
###############################################################################
#
# ڡ⥸塼
#
###############################################################################
package plugin::admin::AdminPageHandler;
#use plugin::admin::Login;
#use plugin::attach::Files;

#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	my $login = $wiki->get_login_info();
	
	#if(!defined($login)){
	#	return $wiki->error("󤷤Ƥޤ");
	#} elsif($login->{type}!=0){
	#	return $wiki->error("Ը¤ɬפǤ");
	#}
	
	if($cgi->param("freeze") ne ""){
		$self->freeze_page($wiki);
		
	} elsif($cgi->param("unfreeze") ne ""){
		$self->unfreeze_page($wiki);
		
	} elsif($cgi->param("delete") ne ""){
		$self->delete_page($wiki);
	}
	return $self->page_list($wiki);
}

#==============================================================================
# ڡκ
#==============================================================================
sub delete_page {
	my $self = shift;
	my $wiki = shift;
	
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->save_page($_,"");
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub freeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 1;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 0;
				last;
			}
		}
		if($flag){
			$wiki->freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub unfreeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 1;
				last;
			}
		}
		if($flag){
			$wiki->un_freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub page_list {
	my $self = shift;
	my $wiki = shift;
	
	my @freeze_list = $wiki->get_freeze_list();
	my @pages = $wiki->get_page_list();
	
	my $buf = "<form action=\"$main::script_name\" method=\"POST\">\n".
	          "<table>\n".
	          "<tr>\n".
	          "  <th><br></th>\n".
	          "  <th></th>\n".
#	          "  <th>ź</th>\n".
	          "  <th>ڡ̾</th>\n".
	          "  <th>ǽ</th>\n".
	          "</tr>\n";
	
	foreach my $page (@pages){
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"pages\" value=\"".Util::escapeHTML($page)."\"></td>\n";
		
		# 뤵Ƥ뤫Ĵ٤
		my $is_freeze = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$is_freeze = 1;
				last;
			}
		}
		if($is_freeze){
			$buf .= "  <td align=\"center\"></td>\n";
		} else {
			$buf .= "  <td><br></td>\n";
		}
		
		# źեե뤬뤫Ĵ٤
#		my @file_list = plugin::attach::Files::get_file_list($page);
#		if($#file_list != -1){
#			$buf .= "  <td align=\"center\">".
#			           "<a href=\"$main::script_name?action=ADMINFILE&page=".Util::url_encode($page)."\">ͭ</a>".
#			           "</td>\n";
#		} else {
#			$buf .= "  <td><br></td>\n";
#		}
		
		$buf .= "  <td><a href=\"$main::script_name?page=".Util::url_encode($page)."\">".Util::escapeHTML($page)."</a></td>\n".
		        "  <td>".Util::format_date($wiki->get_last_modified($page))."</td>\n".
		        "</tr>\n";
	}
	$buf .= "</table>\n".
	        "<br>\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINPAGE\">\n".
	        "<input type=\"submit\" name=\"freeze\" value=\"   \">\n".
	        "<input type=\"submit\" name=\"unfreeze\" value=\"\">\n".
	        "<input type=\"submit\" name=\"delete\" value=\"   \">\n".
	        "</form>\n";
	
	$wiki->set_title("ڡδ");
	return $buf."</ul>\n";
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/admin/AdminPageHandler.pm <==
###############################################################################
#
# ڡ⥸塼
#
###############################################################################
package plugin::admin::AdminPageHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	my $login = $wiki->get_login_info();
	
	if($cgi->param("freeze") ne ""){
		$self->freeze_page($wiki);
		
	} elsif($cgi->param("unfreeze") ne ""){
		$self->unfreeze_page($wiki);
		
	} elsif($cgi->param("delete") ne ""){
		$self->delete_page($wiki);
	}
	return $self->page_list($wiki);
}

#==============================================================================
# ڡκ
#==============================================================================
sub delete_page {
	my $self = shift;
	my $wiki = shift;
	
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->save_page($_,"");
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub freeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 1;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 0;
				last;
			}
		}
		if($flag){
			$wiki->freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub unfreeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 1;
				last;
			}
		}
		if($flag){
			$wiki->un_freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub page_list {
	my $self = shift;
	my $wiki = shift;
	
	my @freeze_list = $wiki->get_freeze_list();
	my @pages = $wiki->get_page_list();
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "<table>\n".
	          "<tr>\n".
	          "  <th><br></th>\n".
	          "  <th></th>\n".
#	          "  <th>ź</th>\n".
	          "  <th>ڡ̾</th>\n".
	          "  <th>ǽ</th>\n".
	          "</tr>\n";
	
	foreach my $page (@pages){
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"pages\" value=\"".&Util::escapeHTML($page)."\"></td>\n";
		
		# 뤵Ƥ뤫Ĵ٤
		my $is_freeze = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$is_freeze = 1;
				last;
			}
		}
		if($is_freeze){
			$buf .= "  <td align=\"center\"></td>\n";
		} else {
			$buf .= "  <td><br></td>\n";
		}
		
		$buf .= "  <td><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($page)."\">".&Util::escapeHTML($page)."</a></td>\n".
		        "  <td>".&Util::format_date($wiki->get_last_modified($page))."</td>\n".
		        "</tr>\n";
	}
	$buf .= "</table>\n".
	        "<br>\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINPAGE\">\n".
	        "<input type=\"submit\" name=\"freeze\" value=\"   \">\n".
	        "<input type=\"submit\" name=\"unfreeze\" value=\"\">\n".
	        "<input type=\"submit\" name=\"delete\" value=\"   \">\n".
	        "</form>\n";
	
	$wiki->set_title("ڡδ");
	return $buf."</ul>\n";
}

1;
